
# Slot: disrupts


describes a relationship where one entity degrades or interferes with the structure, function, or occurrence of another.

URI: [biolink:disrupts](https://w3id.org/biolink/vocab/disrupts)


## Domain and Range

[NamedThing](NamedThing.md) &#8594;  <sub>0..\*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [affects](affects.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | SEMMEDDB:DISRUPTS |
|  | | SEMMEDDB:disrupts |
|  | | CHEMBL.MECHANISM:disrupting_agent |
| **Narrow Mappings:** | | RO:0004024 |
|  | | RO:0004025 |
|  | | RTXKG1:disease_causes_disruption_of |

